(*
===============================================================================================
Name    : Main.pas

Projekt : Charset Demo for Delphi 7

Inhalt  : Main Windows

Stefan Heymann - Firebird Conference 2006 - www.destructor.de
===============================================================================================
This example uses Jason Wharton's IbObjects components   www.ibobjects.com
and it uses Troy Wolbrink's TNT Unicode VCL components   www.tntware.com

Fields of table TEST:
TEST_ID, STR_UTF8, STR_ISO8859_1, STR_ISO8859_2, STR_KOI8R, STR_NONE, STR_ASCII, STR_WIN1252
===============================================================================================
*)

unit Main;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, ExtCtrls, StdCtrls, XPMan,
  IB_Constants, IB_Components, TntStdCtrls, DB, IBODataset, DBCtrls, Grids,
  DBGrids, TntDBGrids, Mask, TntDBCtrls,
  JclUnicode, Charsets, ShellApi;

const
  DATABASE_NAME = 'localhost/3052:charsetdemo';
              //             |__| ^^^^^^^^^^^-- Firebird Alias from {FirebirdDir}\aliases.conf
              //               |
              //               +-- I'm using port 3052 for my Firebird 2.0 server (fbserver -a -p 3052)

type
  TFrmMain = class(TForm)
    PnlTop: TPanel;
    ImgLogo: TImage;
    Label1: TLabel;
    Conn: TIB_Connection;
    Trans: TIB_Transaction;
    GrdInsert: TGroupBox;
    TntLabel1: TTntLabel;
    EdtUtf8: TTntEdit;
    TntLabel2: TTntLabel;
    EdtIso8859_1: TTntEdit;
    TntLabel3: TTntLabel;
    EdtIso8859_2: TTntEdit;
    TntLabel4: TTntLabel;
    EdtWin1252: TTntEdit;
    TntLabel5: TTntLabel;
    EdtNone: TTntEdit;
    TntLabel6: TTntLabel;
    EdtAscii: TTntEdit;
    TntLabel7: TTntLabel;
    EdtKoi8R: TTntEdit;
    BtnInsert: TTntButton;
    GrpViewRecords: TTntGroupBox;
    DBNavigator1: TDBNavigator;
    Qry: TIBOQuery;
    TntLabel8: TTntLabel;
    TntLabel9: TTntLabel;
    TntLabel10: TTntLabel;
    TntLabel11: TTntLabel;
    TntLabel12: TTntLabel;
    TntLabel13: TTntLabel;
    TntLabel14: TTntLabel;
    EdtUtf8Out: TTntEdit;
    EdtIso8859_1Out: TTntEdit;
    EdtIso8859_2Out: TTntEdit;
    EdtWin1252Out: TTntEdit;
    EdtNoneOut: TTntEdit;
    EdtAsciiOut: TTntEdit;
    EdtKoi8ROut: TTntEdit;
    XPManifest: TXPManifest;
    Label2: TLabel;
    Label3: TLabel;
    LblAnsi: TLabel;
    Label5: TLabel;
    LblEastEurope: TLabel;
    Label7: TLabel;
    LblGreek: TLabel;
    Label9: TLabel;
    LblBaltic: TLabel;
    Label4: TLabel;
    LblRussian: TLabel;
    Label6: TLabel;
    LblNoCharset: TLabel;
    Label8: TLabel;
    Label10: TLabel;
    BtnReset: TButton;
    Dsr: TDataSource;
    procedure FormShow(Sender: TObject);
    procedure BtnInsertClick(Sender: TObject);
    procedure QryAfterScroll(DataSet: TDataSet);
    procedure Label8Click(Sender: TObject);
    procedure Label10Click(Sender: TObject);
    procedure BtnResetClick(Sender: TObject);
  private
  public
  end;

var
  FrmMain: TFrmMain;

// ============================================================================================
// IMPLEMENTATION
// ============================================================================================

implementation

{$R *.dfm}

procedure TFrmMain.FormShow(Sender: TObject);
begin
  Conn.LoginPrompt  := FALSE;
  Conn.Username     := 'SYSDBA';
  Conn.Password     := 'masterkey';
  Conn.Database     := DATABASE_NAME;
  Conn.SqlDialect   := 3;
  Conn.CharSet      := 'UTF8';     // Client Character Set

  try
    Conn.Open;
  except
    MessageBox (Handle, PChar (Exception (ExceptObject).Message), 'Charset Demo', mb_IconStop or mb_OK);
    PostQuitMessage(1);
    exit;
    end;

  Qry.Open;
end;


procedure TFrmMain.BtnInsertClick(Sender: TObject);
var
  C : TIB_Cursor;
begin
  C := TIB_Cursor.Create (NIL);
  try
    C.IB_Transaction := Trans;
    C.SQL.Add ('INSERT INTO TEST (TEST_ID, STR_UTF8, STR_ISO8859_1, STR_ISO8859_2, STR_KOI8R, ');
    C.SQL.Add ('  STR_NONE, STR_ASCII, STR_WIN1252) VALUES (');
    C.SQL.Add ('  GEN_ID (TEST_ID, 1), ');
    C.SQL.Add ('  :UTF8, :ISO8859_1, :ISO8859_2, :KOI8R, :NONE, :ASCII, :WIN1252)');

    C.ParamByName ('UTF8').AsString      := WideStringToUTF8 (EdtUtf8.Text);
    C.ParamByName ('ISO8859_1').AsString := WideStringToUTF8 (EdtIso8859_1.Text);
    C.ParamByName ('ISO8859_2').AsString := WideStringToUTF8 (EdtIso8859_2.Text);
    C.ParamByName ('KOI8R').AsString     := WideStringToUTF8 (EdtKoi8R.Text);
    C.ParamByName ('NONE').AsString      := WideStringToUTF8 (EdtNone.Text);
    C.ParamByName ('ASCII').AsString     := WideStringToUTF8 (EdtAscii.Text);
    C.ParamByName ('WIN1252').AsString   := WideStringToUTF8 (EdtWin1252.Text);

    C.Execute;

    Trans.Commit;

    Qry.Close;
    Qry.Open;
    Qry.Last;
  finally
    C.Free;
    end;
end;

procedure TFrmMain.BtnResetClick(Sender: TObject);
begin
  EdtUtf8.Text := '';
  EdtIso8859_1.Text := '';
  EdtIso8859_2.Text := '';
  EdtKoi8R.Text := '';
  EdtNone.Text := '';
  EdtAscii.Text := '';
  EdtWin1252.Text := '';
end;

procedure TFrmMain.QryAfterScroll(DataSet: TDataSet);
begin
  EdtUtf8Out.Text       := UTF8ToWideString (DataSet.FieldByName ('STR_UTF8').AsString);
  EdtIso8859_1Out.Text  := UTF8ToWideString (DataSet.FieldByName ('STR_ISO8859_1').AsString);
  EdtIso8859_2Out.Text  := UTF8ToWideString (DataSet.FieldByName ('STR_ISO8859_2').AsString);
  EdtKOI8ROut.Text      := UTF8ToWideString (DataSet.FieldByName ('STR_KOI8R').AsString);
  EdtNoneOut.Text       := UTF8ToWideString (DataSet.FieldByName ('STR_NONE').AsString);
  EdtAsciiOut.Text      := UTF8ToWideString (DataSet.FieldByName ('STR_ASCII').AsString);
  EdtWin1252Out.Text    := UTF8ToWideString (DataSet.FieldByName ('STR_WIN1252').AsString);

  LblAnsi.Caption       := WideToWin (UTF8ToWideString (DataSet.FieldByName ('STR_UTF8').AsString), WIN1252_UNICODE);
  LblEastEurope.Caption := WideToWin (UTF8ToWideString (DataSet.FieldByName ('STR_UTF8').AsString), WIN1250_UNICODE);
  LblGreek.Caption      := WideToWin (UTF8ToWideString (DataSet.FieldByName ('STR_UTF8').AsString), WIN1253_UNICODE);
  LblBaltic.Caption     := WideToWin (UTF8ToWideString (DataSet.FieldByName ('STR_UTF8').AsString), WIN1257_UNICODE);
  LblRussian.Caption    := WideToWin (UTF8ToWideString (DataSet.FieldByName ('STR_UTF8').AsString), WIN1251_UNICODE);
  LblNoCharset.Caption  := DataSet.FieldByName ('STR_UTF8').AsString;
end;

procedure TFrmMain.Label8Click(Sender: TObject);
begin
  ShellExecute (Handle, 'open', PChar (IncludeTrailingPathDelimiter (ExtractFilePath (ParamStr (0))) + 'LanguageMix.htm'), '', '', sw_ShowNormal);
end;

procedure TFrmMain.Label10Click(Sender: TObject);
          // You'll have to create a web server directory alias on "charsetdemo" to the the folder with the PHP file
begin
  ShellExecute (Handle, 'open', 'http://localhost/charsetdemo/charsetdemo.php', '', '', sw_ShowNormal);
                 //                               ^^^^^^^^^^^ -- Alias for web server
end;


end.
